from django.utils import six
from django.template import Template, Context


def resolve_path(path, context):
    """Resolve a value given a path and a deeply-nested object

    Arguments:
        path: a dot-separated string
        context: any object, list, dictionary,
            or single-argument callable

    Returns:
        value at the end of the path, or None

    Examples:

        T = namedtuple('T', ['x'])
        context = {"a": [T('y')]}
        resolve_path("a.0.x", context) == 'y'
    """
    parts = path.split('.')
    for part in parts:
        if context is None:
            break
        if callable(context):
            # try to "call" into the context
            try:
                try:
                    # 1. assume it is a method that takes no arguments
                    # and returns a nested object
                    context = context()
                except TypeError:
                    # 2. assume its a method that takes the next part
                    # as the argument
                    context = context(part)
                    continue
            except Exception:
                # fallback: assume this is a special object
                # that we should not call into
                # e.g. a django ManyRelatedManager
                pass

        if isinstance(context, dict):
            context = context.get(part, None)
        elif isinstance(context, list):
            # throws ValueError if part is NaN
            part = int(part)
            try:
                context = context[part]
            except IndexError:
                context = None
                break
        else:
            context = getattr(context, part, None)
    if context and callable(context):
        # if the result is a callable,
        # try to resolve it
        context = context()
    return context


def resolve_template(template, context):
    template = Template(template)
    context = Context(context)
    return template.render(context)


def humanize(value, sep=u', '):
    if value is None:
        value = u'null'
    elif type(value) == bool:
        value = str(value).lower()
    elif isinstance(value, six.string_types):
        pass
    elif isinstance(value, list):
        value = sep.join([humanize(v, sep=sep) for v in value])
    elif isinstance(value, dict):
        value = sep.join(
            ['%s=%s' % (str(k), humanize(v, sep=sep))
                for k, v in six.iteritems(value)]
        )
    else:
        value = str(value)
    return value



import os


def get_integer(key, default=0):
    """Return as an integer.

    Arguments:
        default: a default value used if the environment
            variable is undefined
    """
    value = os.environ.get(key)
    return int(value) if value else default


def get_boolean(key, default=False):
    """Return environment value as a boolean.

    Arguments:
        default: a default value used if the environment
            variable is undefined
    """
    value = os.environ.get(key)
    return value.lower() == 'true' if value else default


def get_string(key, default=''):
    """Return environment value as a string."""
    return os.environ.get(key, default)


def get_list(key, default=None, separator=','):
    """Return environment variable as a list."""
    value = os.environ.get(key)
    default = default or []
    return value.split(separator) if value else default



import os
import importlib
import pkgutil
import sys
from django.conf.urls import url, include
from django.utils import six
try:
    # py2
    from urlparse import urlparse
except Exception:
    # py3
    from urllib.parse import urlparse


def load_urls(relative, namespace=True):
    relative = os.path.dirname(relative)
    base = None
    for p in sys.path:
        if relative.startswith(p):
            base = p

    if base is None:
        raise Exception('%s is not in sys.path (%s)' % (relative, sys.path))

    prefix = relative.replace(base, '').replace('/', '.')
    if prefix.startswith('.'):
        prefix = prefix[1:]
    if prefix:
        prefix = prefix + '.'

    urlpatterns = []
    for _, name, package in pkgutil.iter_modules([relative]):
        if package:
            module_name = '%s%s.urls' % (prefix, name)
            try:
                urls = importlib.import_module(module_name)
            except ImportError as e:
                e = str(e)
                if e.startswith('No module named') and 'urls' in e:
                    continue
                else:
                    raise

            patterns = getattr(urls, 'urlpatterns', None)
            if patterns:
                if namespace:
                    if isinstance(namespace, six.string_types):
                        # use the given string as the prefix
                        name = namespace
                    elif callable(namespace):
                        # call the given method with the module name
                        name = namespace(name)
                    else:
                        # only strings, functions, or True are valid
                        # truthy values for `namespace`
                        assert(namespace is True)
                    urlpatterns.append(
                        url('%s/' % name, include(patterns))
                    )
                else:
                    urlpatterns.extend(patterns)

    return urlpatterns


def get_host(url):
    url = urlparse(url)
    return url.netloc.split(':')[0]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['djx']

package_data = \
{'': ['*']}

install_requires = \
['dj-database-url', 'dj-static', 'django', 'gunicorn']

setup_kwargs = {
    'name': 'djx',
    'version': '0.0.6',
    'description': 'Common utilities and dependencies for the modern Django project',
    'long_description': None,
    'author': 'aleontiev',
    'author_email': 'alonetiev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3',
}


setup(**setup_kwargs)
